@@ -3,16 +3,15 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Combinatorial algorithms to generate rhythms
 
-our $VERSION = '0.0602';
+our $VERSION = '0.0700';
 
 use Moo;
 use strictures 2;
 use Algorithm::Combinatorics qw(permutations);
-use Carp qw(croak);
 use Data::Munge qw(list2re);
 use Integer::Partition ();
 use List::Util qw(all any);
-use Math::NumSeq::SqrtContinued ();
+use Music::CreatingRhythms::SqrtContinued ();
 use Math::Sequence::DeBruijn qw(debruijn);
 use Music::AtonalUtil ();
 use namespace::clean;
@@ -20,7 +19,7 @@ use namespace::clean;
 
 has verbose => (
     is      => 'ro',
-    isa     => sub { croak "$_[0] is not a boolean" unless $_[0] =~ /^[01]$/ },
+    isa     => sub { die "$_[0] is not a boolean" unless $_[0] =~ /^[01]$/ },
     default => sub { 0 },
 );
 
@@ -63,13 +62,13 @@ sub cfcv {
 sub cfsqrt {
     my ($self, $n, $m) = @_;
     $m ||= $n;
-    my @terms;
-    my $seq = Math::NumSeq::SqrtContinued->new(sqrt => $n);
-    for my $i (1 .. $m) {
-        my ($j, $value) = $seq->next;
-        push @terms, $value;
-    }
-    return \@terms;
+    my $seq = Music::CreatingRhythms::SqrtContinued->new(
+        sqrt  => $n,
+        terms => $m,
+    );
+    my $terms = $seq->get_seq;
+    warn "OEIS terms less than $m!\n" if @$terms < $m;
+    return $terms;
 }
 
 
@@ -599,7 +598,7 @@ Music::CreatingRhythms - Combinatorial algorithms to generate rhythms
 
 =head1 VERSION
 
-version 0.0602
+version 0.0700
 
 =head1 SYNOPSIS
 
@@ -1024,6 +1023,8 @@ L<Moo>
 
 L<Music::AtonalUtil>
 
+L<Music::CreatingRhythms::SqrtContinued>
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
